------------------------------------------------------------------------
--     state_machine.vhd -- a simple state machine for this stopwatch
------------------------------------------------------------------------
-- Author:  Cong He
--          Copyright 2012 Digilent, Inc.
------------------------------------------------------------------------
-- This module implements a state machine for the features of this 
-- stopwatch. It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		rst		- sets state to stop
--		cclk		- controls next state logic
--		startBtn - starts watch
--		stopBtn  - stops watch
--		incBtn	- increments watch
--
--  Outputs:
--		timerEN	- timer enable
--
------------------------------------------------------------------------
-- Revision History:
--  3/30/2012(HC): Created
------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity state_machine is
    Port ( rst,cclk : in STD_LOGIC;
			  startBtn,stopBtn,incBtn : in  STD_LOGIC;
			  timerEN : out STD_LOGIC);
end state_machine;

architecture Behavioral of state_machine is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
	-- None
	
	------------------------------------------------------------------------
	-- General control and timing signals
	------------------------------------------------------------------------
   type states is (start,stop,inc,trap);
	signal currState, nextState : states := stop;
	
	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------
   -- None
	
	------------------------------------------------------------------------
	-- Implementation
	------------------------------------------------------------------------
	
	begin
			
		process (currState, startBtn, stopBtn, incBtn) begin
			case currState is
				when stop =>
					timerEN <= '0';
					if(startBtn = '1') then nextState <= start;
						elsif(incBtn = '1') then nextState <= inc;
						else nextState <= stop;
					end if;
				when start =>
					timerEN <= '1';
						if(stopBtn = '1') then nextState <= stop;
						else nextState <= start;
					end if;
				when inc =>
					timerEN <= '1';
					nextState <= trap;
				when trap =>
					timerEN <= '0';
					if(incBtn = '0') then nextState <= stop;
						else nextState <= trap;
					end if;
			end case;
		end process;

		process (cclk,rst) begin
			if (rst = '1') then currState <= stop;
				elsif (cclk'event and cclk = '1') then currState <= nextState;
			end if;
		end process;			

	end Behavioral;

