------------------------------------------------------------------------
--     counter.vhd -- A 4 digit counter
------------------------------------------------------------------------
-- Author:  Cong He
--          Copyright 2012 Digilent, Inc.
------------------------------------------------------------------------
-- This module implement a 4 digit counter.
-- It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		rst		- Resets counters
--		cclk	   - 1Khz clock that runs counter
--    timerEN  - timer enable
--
--  Outputs:
--		cntr1-4	- Each counter represents a digit.
--
------------------------------------------------------------------------
-- Revision History:
--  3/30/2012(HC): Created
------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity counter is
    Port ( rst, cclk : in  STD_LOGIC;
			  timerEN : in STD_LOGIC;
           cntr : inout  STD_LOGIC_VECTOR (23 downto 0));
end counter;

architecture Behavioral of counter is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
	-- None
	
	------------------------------------------------------------------------
	-- General control and timing signals
	------------------------------------------------------------------------
   signal C1en, C2en, C3en, C4en, C5en, C6en : STD_LOGIC;
	signal C1tc, C2tc, C3tc, C4tc, C5tc, C6tc : STD_LOGIC;

	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------
   -- None
	
	------------------------------------------------------------------------
	-- Implementation
	------------------------------------------------------------------------

	begin

		process (cclk, rst) begin
			if rst = '1' then cntr <= (others=>'0');
			elsif cclk = '1' and cclk'Event then
				if (C1en = '1') then
					 if cntr(3 downto 0) = "1001" then cntr(3 downto 0) <= "0000"; else cntr(3 downto 0) <= cntr(3 downto 0) + 1; end if;
				end if;
				if (C2en = '1') then
					 if cntr(7 downto 4) = "1001" then cntr(7 downto 4) <= "0000"; else cntr(7 downto 4) <= cntr(7 downto 4) + 1; end if;
				end if;
				if (C3en = '1') then
					 if cntr(11 downto 8) = "1001" then cntr(11 downto 8) <= "0000"; else cntr(11 downto 8) <= cntr(11 downto 8) + 1; end if;
				end if;
				if (C4en = '1') then
					 if cntr(15 downto 12) = "1001" then cntr(15 downto 12) <= "0000"; else cntr(15 downto 12) <= cntr(15 downto 12) + 1; end if;
				end if;
				if (C5en = '1') then
					 if cntr(19 downto 16) = "1001" then cntr(19 downto 16) <= "0000"; else cntr(19 downto 16) <= cntr(19 downto 16) + 1; end if;
				end if;
				if (C6en = '1') then
					 if cntr(23 downto 20) = "1001" then cntr(23 downto 20) <= "0000"; else cntr(23 downto 20) <= cntr(23 downto 20) + 1; end if;
				end if;
			end if;
		end process;
		
		C1tc <= cntr(3) and not cntr(2) and not cntr(1) and cntr(0);
		C2tc <= cntr(7) and not cntr(6) and not cntr(5) and cntr(4);
		C3tc <= cntr(11) and not cntr(10) and not cntr(9) and cntr(8);
		C4tc <= cntr(15) and not cntr(14) and not cntr(13) and cntr(12);
		C5tc <= cntr(19) and not cntr(18) and not cntr(17) and cntr(16);
		C6tc <= cntr(23) and not cntr(22) and not cntr(21) and cntr(20);

		C1en <= timerEN;
		C2en <= C1tc and C1en;
		C3en <= C2tc and C1tc and C1en;
		C4en <= C3tc and C2tc and C1tc and C1en;	
		C5en <= C4tc and C3tc and C2tc and C1tc and C1en;
      C6en <= C5tc and C4tc and C3tc and C2tc and C1tc and C1en;		

	end Behavioral;

