------------------------------------------------------------------------
--     Main.vhd -- Simple stopwatch demo for Nexys3
------------------------------------------------------------------------
-- Author:  Cong He
--          Copyright 2012 Digilent, Inc.
------------------------------------------------------------------------
-- This is the top module of stopwatch demo on Nexys3.
-- It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		clk		- system clock 100MHz
--    swt      - slide switch for timer enable 
--		btn		   - buttons on the Nexys3 board
--
--  Outputs:
--		an		   - anode lines for the 7-seg displays on Nexys3
--		seg		- cathodes (segment lines) for the displays on Nexys3
--
------------------------------------------------------------------------
-- Revision History:
--  3/30/2012(HC): Created
------------------------------------------------------------------------

library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity main is
    Port (clk	: in STD_LOGIC;
	       rst  : in STD_LOGIC;
			 swt  : in STD_LOGIC;
          kypd_row  : in STD_LOGIC_VECTOR(3 downto 0);
			 kypd_col  : out STD_LOGIC_VECTOR(3 downto 0);
          an   : out STD_LOGIC_VECTOR(5 downto 0);
          seg  : out STD_LOGIC_VECTOR(7 downto 0));
end main;

architecture Behavioral of main is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
	
	component clock_divider
		Port (rst,clk : in  STD_LOGIC;
            cclk : out  STD_LOGIC);
	end component;
	
	COMPONENT Decoder
	PORT(
		clk : IN std_logic;
		Row : IN std_logic_vector(3 downto 0);          
		Col : OUT std_logic_vector(3 downto 0);
		DecodeOut : OUT std_logic_vector(3 downto 0);
		kypd_data_en : out  STD_LOGIC_VECTOR (0 downto 0)
		);
	END COMPONENT;

	COMPONENT state_machine
	PORT(
		rst : IN std_logic;
		cclk : IN std_logic;
		kypd_data_en : IN std_logic;          
		push_detected_out : OUT std_logic
		);
	END COMPONENT;

--		
--	component counter
--		Port ( rst, cclk : in  STD_LOGIC;
--			    timerEN : in STD_LOGIC;
--             cntr : out  STD_LOGIC_VECTOR (23 downto 0));
--	end component;
	
	COMPONENT seg_data_ram
	  PORT (
		 clka : IN STD_LOGIC;
		 wea : IN STD_LOGIC_VECTOR(0 DOWNTO 0);
		 addra : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
		 dina : IN STD_LOGIC_VECTOR(3 DOWNTO 0);
		 clkb : IN STD_LOGIC;
		 addrb : IN STD_LOGIC_VECTOR(2 DOWNTO 0);
		 doutb : OUT STD_LOGIC_VECTOR(3 DOWNTO 0)
	  );
	END COMPONENT;
	
	component seven_seg_controller
		Port ( rst, cclk : in STD_LOGIC;
			    dispEN : in STD_LOGIC;
				 segdata : in STD_LOGIC_VECTOR(3 downto 0);
				 seg_select : out STD_LOGIC_VECTOR(2 downto 0);
			    seg : out STD_LOGIC_VECTOR(7 downto 0);
			    an : out STD_LOGIC_VECTOR(5 downto 0));
	end component;
		
	------------------------------------------------------------------------
	-- General control and timing signals
	------------------------------------------------------------------------		

	signal cclk, clk_4ms, dispEN : STD_LOGIC;
	
	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------
	signal segdat : STD_LOGIC_VECTOR(3 downto 0);
	
	signal seven_seg_d : STD_LOGIC_VECTOR(7 downto 0);
	
	signal an_d: STD_LOGIC_VECTOR(5 downto 0);
	
	signal ram_addrb :STD_LOGIC_VECTOR(2 downto 0);
	
	signal ram_addra :STD_LOGIC_VECTOR(2 downto 0);
	
   signal kypd_data_en : STD_LOGIC;
	
	signal push_detected_out : STD_LOGIC_VECTOR(0 downto 0);
	
	signal kypd_ddata : STD_LOGIC_VECTOR(3 downto 0);-- decoded data
	
	signal col_cnt : STD_LOGIC_VECTOR(1 DOWNTO 0);
	
	signal kypd_col_t : STD_LOGIC_VECTOR(3 DOWNTO 0);
	
	signal kypd_row_dly : STD_LOGIC_VECTOR(3 DOWNTO 0);
	------------------------------------------------------------------------
	-- Implementation
	------------------------------------------------------------------------

	begin
	
	Inst_clock_divider: clock_divider PORT MAP(
		rst => rst,
		clk => clk,
		cclk => cclk
	);
	
	Inst_state_machine: state_machine PORT MAP(
		rst => rst,
		cclk => cclk,
		kypd_data_en => kypd_data_en,
		push_detected_out => push_detected_out(0)
	);
	
--	Inst_counter: counter PORT MAP(
--		rst => rst,
--		cclk => cclk,
--		timerEN => timerEN,
--		cntr => cntr
--	);

--	Inst_Decoder: Decoder PORT MAP(
--		clk => clk,
--		Row => kypd_row,
--		Col => kypd_col,
--		DecodeOut => kypd_ddata,
--		kypd_data_en => kypd_data_en
--	);	
	instance_ram : seg_data_ram
	  PORT MAP (
		 clka => clk,
		 wea => push_detected_out,
		 addra => ram_addra,
		 dina => kypd_ddata,
		 clkb => cclk,
		 addrb => ram_addrb,
		 doutb => segdat
	  );
	
	Inst_seven_seg_controller: seven_seg_controller PORT MAP(
		rst => rst,
		cclk => cclk,
		dispEN => dispEN,
		segdata => segdat,
		seg_select => ram_addrb,
		seg => seven_seg_d,
		an => an_d
	);	
	
--	rst <= btn(0); -- button0 to issue a reset signal
--	startBtn <= btn(1); -- start counterting 
--	stopBtn <= btn(2); -- stop counterting
--	incBtn <= btn(3); -- counter number increases 1 after a single press
	dispEN <= swt; -- 7-seg display enable
	
	seg <= not seven_seg_d;
	an <= not an_d;
			 
	process(cclk)
	begin
	   if cclk'event and cclk = '1' then
		   if rst = '1' then
			   kypd_row_dly <= (others =>'0');
			else
			   kypd_row_dly <= kypd_row;
			end if;
		end if;
	end process;
	
	kypd_data_en <= '1' when not(kypd_row=x"f") and kypd_row_dly = x"f" else '0';
	
	process(cclk)
	begin
	   if cclk'event and cclk = '1' then
		   if rst = '1' then
			   ram_addra <= "000";
			else
			   if push_detected_out(0) = '1' then
				   if ram_addra = "101" then
					   ram_addra <= "000";
					else
			         ram_addra <= ram_addra + 1;
					end if;
				end if;
			end if;
		end if;
	end process;
		
	kypd_col_t <= "1110" when col_cnt = "00" else
	            "1101" when col_cnt = "01" else
					"1011" when col_cnt = "10" else
					"0111";
					
	kypd_col <= kypd_col_t;
	
	process(cclk)
	begin
	   if cclk'event and cclk = '1' then
		   if rst = '1' then
			   col_cnt <= (others =>'0');
			else
				col_cnt <= col_cnt + 1;
			end if;
		end if;
	end process;
	
	clk_4ms <= col_cnt(1);

   process(cclk)
	begin
	   if cclk'event and cclk = '1' then
		   if rst = '1' then
			   kypd_ddata <= (others =>'0');
			else
				if kypd_col_t = "1110" then
				   if kypd_row = "1110" then
					   kypd_ddata <= x"1";
					elsif kypd_row = "1101" then
					   kypd_ddata <= x"4";
					elsif kypd_row = "1011" then
					   kypd_ddata <= x"7";
					elsif kypd_row = "0111" then
					   kypd_ddata <= x"0";
					end if;
				elsif kypd_col_t = "1101" then
				   if kypd_row = "1110" then
					   kypd_ddata <= x"2";
					elsif kypd_row = "1101" then
					   kypd_ddata <= x"5";
					elsif kypd_row = "1011" then
					   kypd_ddata <= x"8";
					elsif kypd_row = "0111" then
					   kypd_ddata <= x"f";
					end if;
				elsif kypd_col_t = "1011" then
				   if kypd_row = "1110" then
					   kypd_ddata <= x"3";
					elsif kypd_row = "1101" then
					   kypd_ddata <= x"6";
					elsif kypd_row = "1011" then
					   kypd_ddata <= x"9";
					elsif kypd_row = "0111" then
					   kypd_ddata <= x"e";
					end if;
				elsif kypd_col_t = "0111" then
				   if kypd_row = "1110" then
					   kypd_ddata <= x"a";
					elsif kypd_row = "1101" then
					   kypd_ddata <= x"b";
					elsif kypd_row = "1011" then
					   kypd_ddata <= x"c";
					elsif kypd_row = "0111" then
					   kypd_ddata <= x"d";
					end if;
				end if;
			end if;
		end if;
	end process;	
	
end Behavioral;