------------------------------------------------------------------------
--     state_machine.vhd -- a simple state machine for this stopwatch
------------------------------------------------------------------------
-- Author:  Cong He
--          Copyright 2012 Digilent, Inc.
------------------------------------------------------------------------
-- This module implements a state machine for the features of this 
-- stopwatch. It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		rst		- sets state to stop
--		cclk		- controls next state logic
--		startBtn - starts watch
--		stopBtn  - stops watch
--		incBtn	- increments watch
--
--  Outputs:
--		timerEN	- timer enable
--
------------------------------------------------------------------------
-- Revision History:
--  3/30/2012(HC): Created
------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity state_machine is
    Port ( rst,cclk : in STD_LOGIC;
			  kypd_data_en: in  STD_LOGIC;
			  push_detected_out : out STD_LOGIC
			 );
end state_machine;

architecture Behavioral of state_machine is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
	-- None
	
	------------------------------------------------------------------------
	-- General control and timing signals
	------------------------------------------------------------------------
   type states is (idle,detect,waitforidle);
	signal currState, nextState : states := idle;
	
	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------
   signal detect_cnt_en, detect_cnt_rst,push_detected : STD_LOGIC;
	signal detect_cnt: STD_LOGIC_VECTOR(5 downto 0);
	
	------------------------------------------------------------------------
	-- Implementation
	------------------------------------------------------------------------
	
	begin
			
		process (currState) begin
			case currState is
				when idle =>
					detect_cnt_en <= '0';
					push_detected <= '0';
					detect_cnt_rst <= '1';
				when detect =>
					detect_cnt_en <= '0';
					push_detected <= '1';
					detect_cnt_rst <= '0';
				when waitforidle =>
					detect_cnt_en <= '1';
					push_detected <= '0';
					detect_cnt_rst <= '0';
				when others =>
					detect_cnt_en <= '0';
					push_detected <= '0';
					detect_cnt_rst <= '1';
			end case;
		end process;

      push_detected_out <= push_detected;
		
		process (currState, kypd_data_en) begin
		   nextState <= currState;
			case currState is			   
				when idle =>
					if(kypd_data_en = '1') then 
						 nextState <= detect;
					end if;
				when detect =>				
						 nextState <= waitforidle;
				when waitforidle =>
					if(detect_cnt > x"f") then 
						 nextState <= idle;
					end if;
				when others =>
					nextState <= idle;
			end case;
		end process;
		
		process (cclk,rst) begin
			if (rst = '1') then currState <= idle;
				elsif (cclk'event and cclk = '1') then currState <= nextState;
			end if;
		end process;	

		process(cclk)
		begin
			if cclk'event and cclk = '1' then
				if rst = '1' or detect_cnt_rst = '1' then
					detect_cnt <= (others =>'0');
				else
				   if kypd_data_en = '1' then
					   detect_cnt <= (others =>'0');
				   elsif detect_cnt_en = '1' then
					   detect_cnt <= detect_cnt + 1;
					end if;
				end if;
			end if;
		end process;		

	end Behavioral;

