
library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

entity anvyl_vga is
   Port(
		SYS_CLK_I 	: in  std_logic;
      VSYNC_O		: out std_logic;
		HSYNC_O		: out std_logic;
		RED_O			: out std_logic_vector(2 downto 0);
		GREEN_O		: out std_logic_vector(2 downto 0);
		BLUE_O		: out std_logic_vector(1 downto 0)
	);
end anvyl_vga;

architecture Behavioral of anvyl_vga is

	component clk25m
		port(-- Clock in ports
			CLK_IN1           : in     std_logic;
			-- Clock out ports
			CLK_OUT1          : out    std_logic
		);
	end component;

	-- Sychronize Signals Generator
	component sync_gen
      Port( 
			PIX_CLK_I		: in  std_logic;
			HSYNC_O			: out std_logic;
			VSYNC_O			: out std_logic;
			PIX_CNT_O		: out std_logic_vector (9 downto 0);
			LINE_CNT_O		: out std_logic_vector (9 downto 0)			 
		);
   end component;

   signal pix_clk   : STD_LOGIC := '0'; --Divided clock
	signal line_cnt  : STD_LOGIC_VECTOR (9 DOWNTO 0);-- V line
	signal pix_cnt : STD_LOGIC_VECTOR (9 DOWNTO 0);-- H pixel

begin

	clk_gen_inst	:	clk25m
		port map(-- Clock in ports
		CLK_IN1	=>	SYS_CLK_I,
		-- Clock out ports
		CLK_OUT1	=>	pix_clk
		);

   SYNC_GEN_INST : sync_gen
      port map (
			PIX_CLK_I  => pix_clk,
			HSYNC_O      => HSYNC_O,
			VSYNC_O  => VSYNC_O,
			PIX_CNT_O => pix_cnt,
			LINE_CNT_O      => line_cnt
			);

	RED_O		<=	(others => '0');
	GREEN_O	<=	pix_cnt(4	downto	2);
	BLUE_O	<=	pix_cnt(1	downto	0);

end Behavioral;
