/*
 * Copyright (c) 2009 Xilinx, Inc.  All rights reserved.
 *
 * Xilinx, Inc.
 * XILINX IS PROVIDING THIS DESIGN, CODE, OR INFORMATION "AS IS" AS A
 * COURTESY TO YOU.  BY PROVIDING THIS DESIGN, CODE, OR INFORMATION AS
 * ONE POSSIBLE   IMPLEMENTATION OF THIS FEATURE, APPLICATION OR
 * STANDARD, XILINX IS MAKING NO REPRESENTATION THAT THIS IMPLEMENTATION
 * IS FREE FROM ANY CLAIMS OF INFRINGEMENT, AND YOU ARE RESPONSIBLE
 * FOR OBTAINING ANY RIGHTS YOU MAY REQUIRE FOR YOUR IMPLEMENTATION.
 * XILINX EXPRESSLY DISCLAIMS ANY WARRANTY WHATSOEVER WITH RESPECT TO
 * THE ADEQUACY OF THE IMPLEMENTATION, INCLUDING BUT NOT LIMITED TO
 * ANY WARRANTIES OR REPRESENTATIONS THAT THIS IMPLEMENTATION IS FREE
 * FROM CLAIMS OF INFRINGEMENT, IMPLIED WARRANTIES OF MERCHANTABILITY
 * AND FITNESS FOR A PARTICULAR PURPOSE.
 *
 */

/*
 * helloworld.c: simple test application
 */

#include <stdio.h>
#include "platform.h"
#include "xparameters.h"
#include "xil_io.h"

#define	ADDR_OFF_RC_FIFO	0x10c
#define	ADDR_OFF_RC_FIFO_PIRQ	0x120
#define	ADDR_OFF_CR	0x100
#define	ADDR_OFF_TX_FIFO	0x108
#define	ADDR_OFF_SR	0x104

#define	BITS_RST_TX_FIFO	0x2
#define	BITS_EN	0x1
#define	BITS_GEN_CALL	0x40
#define	BITS_START	0x100
#define	BITS_STOP	0x200
#define	bitIicTxEpt			0x80

void print(char *str);
void init_iic(u32 lIicBaseAddress);
u32 CodecIicSingleWrite(u32 lIicBaseAddress, u8 codecregaddr, u8 data);
void Delay(unsigned int msec);

void Delay(unsigned int msec) {
	int count = 0;

	for(count = 0; count < msec * XPAR_MICROBLAZE_0_FREQ / 1000; count++) {
		asm("nop");
	}
}
void init_iic(u32 lIicBaseAddress)
{
	u32 regCodecIicCR;
	    /* Set Receive FIFO Programmable Depth Interrupt Register (C_BASEADDR + 0x120) */
		Xil_Out32(lIicBaseAddress + ADDR_OFF_RC_FIFO_PIRQ, 0xF);

		/* Reset Transmission FIFO */
		regCodecIicCR = Xil_In32(lIicBaseAddress + ADDR_OFF_CR);
		regCodecIicCR = regCodecIicCR | BITS_RST_TX_FIFO;
		Xil_Out32(lIicBaseAddress + ADDR_OFF_CR, regCodecIicCR);

		regCodecIicCR = Xil_In32(lIicBaseAddress + ADDR_OFF_CR);
		regCodecIicCR = regCodecIicCR & (~BITS_RST_TX_FIFO) & (~BITS_GEN_CALL); // General call disabled, Transmit FIFO normal operation
		regCodecIicCR = regCodecIicCR | BITS_EN; // Enables IIC Controller
		Xil_Out32(lIicBaseAddress + ADDR_OFF_CR, regCodecIicCR);
}

u32 CodecIicSingleWrite(u32 lIicBaseAddress, u8 codecregaddr, u8 data){

	while(!(bitIicTxEpt & Xil_In32(lIicBaseAddress+ADDR_OFF_SR))){
		asm("nop");
	}

	Xil_Out32(lIicBaseAddress + ADDR_OFF_TX_FIFO, 0x34 | BITS_START);
	Xil_Out32(lIicBaseAddress + ADDR_OFF_TX_FIFO, codecregaddr);
	Xil_Out32(lIicBaseAddress + ADDR_OFF_TX_FIFO, data | BITS_STOP);

	Delay(10);

	return 0;
}

int main()
{
    init_platform();

    print("Hello World\n\r");

    init_iic(XPAR_IIC_0_BASEADDR);

    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x0c, 0x17);//power management without output

//    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x01, 0x3f);//input ADC

    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x05, 0x7f);//output DAC, 6db 

//    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x08, 0x1a);//analog path

    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x0e, 0x09);//digital if,left justfied

    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x10, 0x00);//sampling rate 48KHz

    Delay(100);// wait to active digital core
    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x12, 0x01);//active digital core

    CodecIicSingleWrite(XPAR_IIC_0_BASEADDR, 0x0c, 0x07);// power on output

    Xil_Out32(XPAR_CODEC_IF_0_BASEADDR,0xffffffff);// enable signal for my codec IP

    cleanup_platform();

    return 0;
}
