------------------------------------------------------------------------
--	FlyingLogo.vhd  -- Template VHDL Source File
------------------------------------------------------------------------
-- Author: He Cong
--	Copyright 2011 Digilent, Inc.
------------------------------------------------------------------------
-- Module description
--   The module displays a moving Digilent Logo on VGA Port
--
--  Inputs:
--		SYS_CLK_I - 100MHz Oscillator Input
--
--  Outputs:
--	   RED_O - 8-bit red channel
--	   GREEN_O - 8-bit green channel
--	   BLUE_O - 8-bit blue channel
--	   HSYNC_O - horizontal synchronize signal
--	   VSYNC_O - vertical synchronize signal
--
------------------------------------------------------------------------
-- Revision History:
--
--	13Apr2011(CongH): created
--	13Apr2011(SteveW): coding sytle
--
------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity flyinglogo is
   Port(
		PIX_CLK_I 	: in  std_logic;
      VSYNC_O		: out std_logic;
		HSYNC_O		: out std_logic;
		DE_O			: out std_logic;
		DATA_O		: out std_logic_vector(23 downto 0)
    );
end flyinglogo;

architecture Behavioral of flyinglogo is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
   
	-- Global Clock Manager
--	component clk_gen
--		port(
--		  -- Clock in ports
--		  CLK_IN1           : in     std_logic;
--		  -- Clock out ports
--		  CLK_OUT1          : out    std_logic
--		);
--   end component;
	
	-- Sychronize Signals Generator
	component sync_gen
      Port( 
			PIX_CLK_I		: in  std_logic;
			HSYNC_O			: out std_logic;
			VSYNC_O			: out std_logic;
			DE_O				: out std_logic;
			PIX_CNT_O		: out std_logic_vector (10 downto 0);
			LINE_CNT_O		: out std_logic_vector (9 downto 0)			 
		);
   end component;

	-- Merge Logo and Background
	component video_merge
      Port( 
			PIX_CLK_I		: in   std_logic;
			PIX_CNT_I		: in   std_logic_vector (10 downto 0);
			LINE_CNT_I		: in   std_logic_vector (9 downto 0);
		   LOGO_DATA_I		: in   std_logic_vector (7 downto 0);
			LOGO_ADDR_O		: out  std_logic_vector (13 downto 0);
			RED_O				: out std_logic_vector(7 downto 0);
			GREEN_O			: out std_logic_vector(7 downto 0);
			BLUE_O			: out std_logic_vector(7 downto 0)
		);
   end component;
	
	-- Logo BRAM
	component bram
		port (
			clka				: in std_logic;
			wea				: in std_logic_vector(0 downto 0);
			addra				: in std_logic_vector(13 downto 0);
			dina				: in std_logic_vector(7 downto 0);
			douta				: out std_logic_vector(7 downto 0)
		);
	end component;


	------------------------------------------------------------------------
	-- Signals Declarations
	------------------------------------------------------------------------

   signal pix_clk   : STD_LOGIC := '0'; --Divided clock
	signal line_cnt  : STD_LOGIC_VECTOR (9 DOWNTO 0);-- V line
	signal pix_cnt : STD_LOGIC_VECTOR (10 DOWNTO 0);-- H pixel

	signal logo_ram_addr : STD_LOGIC_VECTOR (13 downto 0); -- address of bram
	signal logo_ram_data :STD_LOGIC_VECTOR (7 downto 0);   -- data of bram
	
	signal red_i : std_logic_vector(7 downto 0);
	signal green_i : std_logic_vector(7 downto 0);
	signal blue_i : std_logic_vector(7 downto 0);
--	signal draw_x   : STD_LOGIC_VECTOR (10 DOWNTO 0); -- animation x
--	signal draw_y   : STD_LOGIC_VECTOR (9 DOWNTO 0); -- animation y
	

	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------

------------------------------------------------------------------------
-- Implementation
------------------------------------------------------------------------
begin

--	CLK_GEN_INST : clk_gen
--		port map(
--			-- Clock in ports
--			CLK_IN1  		=> SYS_CLK_I,
--			-- Clock out ports
--			CLK_OUT1			=> pix_clk
--	      );
	
	pix_clk <= PIX_CLK_I;
	
   SYNC_GEN_INST : sync_gen
      port map (
			PIX_CLK_I  => pix_clk,
			HSYNC_O      => HSYNC_O,
			VSYNC_O  => VSYNC_O,
			DE_O => DE_O,
			PIX_CNT_O => pix_cnt,
			LINE_CNT_O => line_cnt
			);
			
	VIDEO_MERGE_INST : video_merge
      port map (
			PIX_CLK_I  => pix_clk,
			PIX_CNT_I => pix_cnt,
			LINE_CNT_I  => line_cnt,
			LOGO_DATA_I    => logo_ram_data,
			LOGO_ADDR_O   => logo_ram_addr,
			RED_O  => red_i,
			GREEN_O => green_i,
			BLUE_O => blue_i
			);

	LOGO_BRAM_INST : bram
		port map (
			clka => pix_clk,
			wea => "0",
			addra => logo_ram_addr,
			dina => x"00",
			douta => logo_ram_data
			);

	DATA_O <= red_i & green_i & blue_i;

end Behavioral;

