----------------------------------------------------------------------------------
-- Company: Digilent  
-- Engineer: Yao Qi
-- 
-- Create Date:    09:20:39 03/30/2012 
-- Design Name: 
-- Module Name:    Top - Behavioral 
-- Project Name: 
-- Target Devices:  Nexys3
-- Tool versions:  ISE 13.4
-- Description: 
--              Pmod AD1 reference Design on Nexys3
--              use eight LEDs as 8bit digital output and use JB port as analog output
--              BTNU as start signal for reading Data from ADC7476 chip.
--              BTNS as restart signal for whole control system
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Top is
    Port ( 
     --General usage
           Clk 	: in  STD_LOGIC;
     --Buttons
           BTN0 	: in  STD_LOGIC;
           BTN1 	: in  STD_LOGIC;
     --Switch
           SW 		: in  STD_LOGIC_VECTOR (7 downto 0);
     --LED
			  LED		: out std_logic_vector(7 downto 0);
            
      --Pmod AD1 interface signals, JB port
           AD_CS    : out std_logic;
           AD_SClk  : out std_logic;
           AD_SDataB : in std_logic;
           AD_SDataA : in std_logic;
			  AD_Done_LED: out std_logic);
           
end Top;

architecture Behavioral of Top is
-- system signals of system
signal RST		: std_logic;

-- internal signals of AD module
signal AD_DataA		: std_logic_vector(11 downto 0);
signal AD_DataB		: std_logic_vector(11 downto 0);
signal AD_Start     : std_logic;
signal AD_Done      : std_logic;


begin
-- System Reset input
    RST <= BTN1;
-- start signal for AD module
    AD_Start <= BTN0;
-- use 8bit LED as high 8bits of AD digital outout,
    LED <= AD_DataA(11 downto 4);
-- Done led
    AD_Done_LED <= AD_Done;

AD1_inst : entity work.AD1
    port map(
  --General usage
    CLK      => Clk,
    RST      => RST,
     
  --Pmod interface signals
    SDATA1   => AD_SDataA,
    SDATA2   => AD_SDataB,
    SCLK     => AD_SClk,
    nCS      => AD_CS,
        
    --User interface signals
    DATA1    => AD_DataA,
    DATA2    => AD_DataB,
    START    => AD_Start, 
    DONE     => AD_Done
    );

end Behavioral;

