----------------------------------------------------------------------------------
-- Company: Digilent  
-- Engineer: Yao Qi
-- 
-- Create Date:    09:20:39 03/30/2012 
-- Design Name: 
-- Module Name:    Top - Behavioral 
-- Project Name: 
-- Target Devices:  Nexys3
-- Tool versions:  ISE 13.2
-- Description: 
--              Pmod DA2 reference Design on Nexys3
--              use eight swiths as 8bit digital input and use JA port as analog output
--              BTND as start signal for writing Data into DAC121s101 chip.
--              BTNS as restart signal for whole control system
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity Top is
    Port ( Clk 	: in  STD_LOGIC;
           BTN0 	: in  STD_LOGIC;
           BTN1 	: in  STD_LOGIC;
           SW 		: in  STD_LOGIC_VECTOR (7 downto 0);
		     LED		: out std_logic_vector(7 downto 0);
           Sync 	: out  STD_LOGIC;
           DinA 	: out  STD_LOGIC;
           DinB 	: out  STD_LOGIC;
           SClk 	: out  STD_LOGIC);
end Top;

architecture Behavioral of Top is

signal Data		: std_logic_vector(11 downto 0);
signal RST		: std_logic;
signal Clk_50MHz : std_logic;

begin
-- System Reset input
    RST <= BTN1;
--Default LED
    LED(7 downto 1) <= "0000000";

-- use 8bit swith as high 8bits of digital input, the low 4bits set as 0;
    Data <= SW & "0000";

DA2_inst : entity work.DA2
	port map(
     --General usage
       CLK      => Clk,    -- System Clock (100MHz)     
       RST      => RST,
     
     --Pmod interface signals
       D1       => DinA,
       D2       => DinB,
       CLK_OUT  => SClk,
       nSYNC    => Sync,
        
     --User interface signals
       DATA1    => Data,
       DATA2    => Data,
       START    => BTN0,
       DONE     => LED(0)
	);

end Behavioral;

