--------------------------------------------------------------------------------
-- Company:    Digilent inc
-- Engineer:   Kovacs Laszlo - Attila
--
-- Create Date:    09:39:11 03/26/07
-- Design Name:    
-- Module Name:    DCmotorHB3 - Behavioral
-- Project Name:   
-- Target Device:  X-Board, PModHB3
-- Tool versions:  
-- Description:
--
-- Dependencies:
-- 
-- Revision:
-- Revision 0.01 - File Created
-- Additional Comments:
-- 
--------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity HB3 is
    Port ( 
      Clk      : in  std_logic;
		rst      : in  std_logic;
      Switch   : in  std_logic_vector(7 downto 0);     
      HB3Dir   : out std_logic;  -- direction
      HB3En    : out std_logic;  -- enable
		led      : out std_logic); -- led test for pwm
end HB3;

architecture Behavioral of HB3 is

-- 100Khz clock
signal clk_100KHz: std_logic;

-- freqency of the PWM
constant pwmfreq  : std_logic_vector (8 downto 0) := "100000000"; -- 64

-- pulse length
signal pwmlen : std_logic_vector(6 downto 0);

-- direction 
signal dir : std_logic := '0';

-- enable
signal en  : std_logic := '0';

-- counted for the frequency and pulse length
signal cnt  : std_logic_vector(7 downto 0) := x"00";

-- refresh and update is used for the new configuration to be loaded 
-- at the end of the PWM cycle to finish the previous configuration and 
-- to not change the direction while it is enabled
signal refresh : std_logic;

	COMPONENT clock_divider
	PORT(
		rst : IN std_logic;
		clk : IN std_logic;       
		cclk : INOUT std_logic
		);
	END COMPONENT;

begin

	Inst_clock_divider: clock_divider PORT MAP(
		rst => rst,
		clk => Clk,
		cclk => clk_100KHz
	);
   
   pwmlen <= Switch(6 downto 0);
   dir    <= Switch(7);
   
   -- end of the PWM cycle
   refresh <= '1' when cnt = pwmfreq - '1' else '0';

   process(clk_100KHz)
   begin
      if rising_edge(clk_100KHz) then
         
         -- start next PWM cycle and count
         if refresh = '1' then
            cnt <= x"00";
         else
            cnt <= cnt + '1';
         end if;
         
         -- deactivate enable when pulse length reached
         -- activate when the PWM cycle is started
         if cnt = '0'&pwmlen then
            en <= '0';
         elsif cnt = x"00" then
            en <= '1';            
         end if;   
      end if;
   end process;

   HB3Dir <= dir;
   HB3En  <= en;
	
	led <= en;
	
end Behavioral;
