------------------------------------------------------------------------
--     clock_divider.vhd -- Simple clock divider
------------------------------------------------------------------------
-- Author:  Cong He
--          Copyright 2012 Digilent, Inc.
------------------------------------------------------------------------
-- This module generates required clock through countering.
-- It was developed using the Xilinx WebPack tools.
--
--  Inputs:
--		rst		- resets counter
--		clk		- main clock
--
--  Outputs:
--		cclk		- 1 Khz Clock
--
------------------------------------------------------------------------
-- Revision History:
--  3/30/2012(HC): Created
------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity clock_divider is
	Port ( rst,clk : in  STD_LOGIC;
          cclk : inout  STD_LOGIC);
end clock_divider;

architecture Behavioral of clock_divider is

	------------------------------------------------------------------------
	-- Component Declarations
	------------------------------------------------------------------------
	-- None
	
	------------------------------------------------------------------------
	-- General control and timing signals
	------------------------------------------------------------------------
   constant KILLCLK : STD_LOGIC_VECTOR  := "111110100"; -- 500

	signal dividedClk : STD_LOGIC;
	signal clkdiv : STD_LOGIC_VECTOR(9 downto 0);

	------------------------------------------------------------------------
	-- Data path signals
	------------------------------------------------------------------------
   -- None
	
	------------------------------------------------------------------------
	-- Implementation
	------------------------------------------------------------------------
	
	begin
		
	process (clk, rst)
		begin
		if rst = '1' then clkdiv <= (others=>'0');
			elsif clk = '1' and clk'Event then
				clkdiv <= clkdiv + 1;
				if(KILLCLK = clkdiv) then
					dividedClk <= not dividedClk;
					clkdiv <= (others=>'0');
				end if;
			end if;
		end process;
		
		cclk <= dividedClk;

	end Behavioral;

