----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    13:38:17 01/05/2012 
-- Design Name: 
-- Module Name:    codec - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.std_logic_unsigned.all;
use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if using
-- arithmetic functions with Signed or Unsigned values
--use IEEE.NUMERIC_STD.ALL;

-- Uncomment the following library declaration if instantiating
-- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity codec is
	Port (  clk_100MHz : in  STD_LOGIC;                        -- system clock 100MHz 
	        clk_200MHz : in  STD_LOGIC; 
			  rst : in  STD_LOGIC;                        -- system reset signal
			  tone : in  std_logic_vector (4 downto 0);   -- 5 buttons as the tone generator
			  wave_mode : in  STD_LOGIC_VECTOR (2 downto 0);   -- select wave shape
			  pwmoutl : out  std_logic;	                -- pwm output for the left speaker 
			  pwmoutr : out  std_logic;  	                -- pwm output for the left speaker
			  mclk_in : in  STD_LOGIC;
			  bclk_out : out  STD_LOGIC;
			  pblrc_out : out  STD_LOGIC;
			  iic_staus_reg: in std_logic_vector(31 downto 0)
			);
end codec;

architecture Behavioral of codec is
	
	COMPONENT clk_div
	PORT(
		clk_in : IN std_logic;
		rst : IN std_logic;          
		clk_50MHz : OUT std_logic
		);
	END COMPONENT;

	COMPONENT SimpleSynth
	PORT(
		ck : IN std_logic;
		tone : IN std_logic_vector(4 downto 0);
		wave_mode : IN std_logic_vector(2 downto 0);          
		audioSample : OUT std_logic_vector(7 downto 0)
		);
	END COMPONENT;
	
--	COMPONENT pulsewm
--	PORT(
--		clk : IN std_logic;
--		clk_200MHz : IN std_logic;
--		x : IN std_logic_vector(7 downto 0);          
--		pwmout : OUT std_logic
--		);
--	END COMPONENT;
	
   signal audioSample : std_logic_vector (7 downto 0);
	signal clk_50MHz : STD_LOGIC;
--	signal clk_100MHz : STD_LOGIC;
--	signal clk_200MHz : STD_LOGIC;
	signal pwmout : STD_LOGIC;
	
	signal cnt : STD_LOGIC_VECTOR (7 downto 0);
	
	signal audio_frame_cnt : integer range 0 to 63;
	
	signal bclk_out_t : STD_LOGIC;
	signal pblrc_out_t : STD_LOGIC;
	signal pblrc_out_t_dly : STD_LOGIC;	
	
	signal pwmoutl_t : STD_LOGIC;
	
	signal bclk_out_reg : STD_LOGIC;
	signal pblrc_out_reg : STD_LOGIC;	
	signal pwmoutl_reg : STD_LOGIC;
	
	signal out_en : STD_LOGIC;
	
	signal data_en_l : STD_LOGIC;
	signal data_en_r : STD_LOGIC;
	signal data_en_l_dly : STD_LOGIC;
	signal data_en_r_dly : STD_LOGIC;
	
	signal pb_data : STD_LOGIC;
	signal audio_data : STD_LOGIC_VECTOR(23 downto 0);
	signal audio_data_reg : STD_LOGIC_VECTOR(23 downto 0);
	
	signal rst_i : STD_LOGIC;
	
	signal data_reg_en : STD_LOGIC;
	
begin

--   bclk_out <= bclk_out_reg;
--	pblrc_out <= pblrc_out_reg;
--	pwmoutl <= pwmoutl_reg;
	
	bclk_out <= not bclk_out_t;
	pblrc_out <= pblrc_out_t_dly;
	pwmoutl <= pb_data;
	
	out_en <= '1' when iic_staus_reg = x"ffffffff" else
	          '0';
   -- sync process
	
	rst_i <= not out_en or rst;
	
--   process(clk_100MHz)
--	begin
--	   if clk_100MHz'event and clk_100MHz = '1' then
--		   if rst_i = '1' then
--			   bclk_out_reg <= '0';
--				pblrc_out_reg <= '0';
--				pwmoutl_reg <= '0';
--			else
--					bclk_out_reg <= not bclk_out_t;
--					pblrc_out_reg <= pblrc_out_t_dly;
--					pwmoutl_reg <= pb_data;
--		   end if;
--		end if;
--	end process;

--	BUFG   cnt_bufg (.O(bclk_out_t), .I(cnt(4)));
	
	bclk_out_t <= cnt(1); -- mclk/4
	
	process(mclk_in)
	begin
	   if mclk_in'event and mclk_in = '1' then
		   if rst_i = '1' then
			   cnt <= (others => '0');
			else
			   cnt <= cnt + 1;
		   end if;
		end if;
	end process;

   process(bclk_out_t)
	begin
	   if bclk_out_t'event and bclk_out_t = '1' then
		   if rst_i = '1' then
			   audio_frame_cnt <= 0;
			else
			   if audio_frame_cnt >= 63 then
				   audio_frame_cnt <= 0;
				else
			      audio_frame_cnt <= audio_frame_cnt + 1;
				end if;
		   end if;
		end if;
	end process;

   pblrc_out_t <= '1' when audio_frame_cnt < 32 else  -- mclk/256
                  '0';
   
	data_en_l <= '1' when audio_frame_cnt < 24 else
	             '0';
					 
	data_en_r <= '1' when audio_frame_cnt > 31 and audio_frame_cnt < 56 else
	             '0';
					 
	data_reg_en <= '1' when audio_frame_cnt = 0 else
	             '0';
	
	audio_data <= audioSample & x"ffff";
	
	process(bclk_out_t)
	begin
	   if bclk_out_t'event and bclk_out_t = '1' then
		   if rst_i = '1' then
			   data_en_l_dly <= '0';
				data_en_r_dly <= '0';
				pblrc_out_t_dly <= '0';
			else
			   data_en_l_dly <= data_en_l;
				data_en_r_dly <= data_en_r;
				pblrc_out_t_dly <= pblrc_out_t;
		   end if;
		end if;
   end process;
	
	process(bclk_out_t)
	begin
	   if bclk_out_t'event and bclk_out_t = '1' then
		   if rst_i = '1' then
			   audio_data_reg <= (others => '0');
			else
			   if data_reg_en = '1' then
				   audio_data_reg <= audio_data;
			   elsif  data_en_l_dly = '1' or data_en_r_dly = '1' then
				   audio_data_reg <= audio_data_reg(22 downto 0) & audio_data_reg(23);
				end if;
		   end if;
		end if;
   end process;

   pb_data <= audio_data_reg(23) when data_en_l_dly = '1' or data_en_r_dly = '1' else '0';
	
	
--	pwmoutl_t <= pwmout;	-- assigning same signal to both left and right channels   
--	pwmoutr <= pwmout;	-- in case of using a stereo headphone  
	 
	Inst_clk_div: clk_div PORT MAP(
		clk_in => clk_100MHz,
		rst => rst_i,
		clk_50MHz => clk_50MHz
	);
	
   Inst_SimpleSynth: SimpleSynth PORT MAP(
		ck => clk_50MHz,
		tone => tone,
		wave_mode => wave_mode,
		audioSample =>audioSample 
	);
	
--   Inst_pulsewm: pulsewm PORT MAP(
--		clk => clk_50MHz,
--		clk_200MHz => clk_200MHz,
--		x => audioSample,
--		pwmout => pwmout
--	);
	
end Behavioral;

