----------------------------------------------------------------------------------
-- Company: Digilent RO
-- Engineer: Mircea DAbacan
-- 
-- Create Date:    16:47:13 12/16/2010 
-- Design Name: 
-- Module Name:    pwm - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--		pwm modulator:
--			input number: x
--			carrier: clk/256 (8 bit)
--			output: pwmout
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
-- Generates the pwm signal 

library IEEE;
use IEEE.std_logic_1164.all;
use IEEE.std_logic_arith.all;
use IEEE.std_logic_signed.all;
Library UNISIM;
use UNISIM.vcomponents.all;

entity pulsewm is
    port (
        clk: in std_logic;							-- system clock = 50.00MHz;
		  clk_200MHz : in std_logic;	
        x: in std_logic_vector (7 downto 0);	-- the number to be modulated
        pwmout: out std_logic						-- the Pulse With Modulated signal
    );
end pulsewm;

architecture pulsewm_arch of pulsewm is

	signal count : std_logic_vector (7 downto 0); 
--	signal ckMul : std_logic; 		-- clock multiplied by 4

begin

	counter: process (clk_200MHz)
	begin
		if clk_200MHz'event and clk_200MHz='1' then		-- the counter rolls over; 
			count <= count + "00000001";	-- the carrier is (clk frequency)/256
		end if;
	end process;

	compare: process (x,count)
	begin
		if unsigned(count) < unsigned(x) then pwmout<='1';	-- x was built as unsigned integer
		else		pwmout<='0';
		end if;
	end process;

--   DCM_SP_inst : DCM_PS
--   generic map (
--      CLKDV_DIVIDE => 2.0, --  Divide by: 1.5,2.0,2.5,3.0,3.5,4.0,4.5,5.0,5.5,6.0,6.5
--                           --     7.0,7.5,8.0,9.0,10.0,11.0,12.0,13.0,14.0,15.0 or 16.0
--      CLKFX_DIVIDE => 1,   --  Can be any interger from 1 to 32
--      CLKFX_MULTIPLY => 4, --  Can be any integer from 1 to 32
--      CLKIN_DIVIDE_BY_2 => FALSE, --  TRUE/FALSE to enable CLKIN divide by two feature
--      CLKIN_PERIOD => 20.0, --  Specify period of input clock
--      CLKOUT_PHASE_SHIFT => "NONE", --  Specify phase shift of "NONE", "FIXED" or "VARIABLE" 
--      CLK_FEEDBACK => "NONE",         --  Specify clock feedback of "NONE", "1X" or "2X" 
--		DCM_PERFORMANCE_MODE => "MAX_SPEED",   -- Can be MAX_SPEED or MAX_RANGE
--      DESKEW_ADJUST => "SYSTEM_SYNCHRONOUS", -- "SOURCE_SYNCHRONOUS", "SYSTEM_SYNCHRONOUS" or
--                                             --     an integer from 0 to 15
--      DFS_FREQUENCY_MODE => "LOW",   -- HIGH or LOW frequency mode for frequency synthesis
--      DLL_FREQUENCY_MODE => "LOW",   -- LOW, HIGH, or HIGH_SER frequency mode for DLL
--      DUTY_CYCLE_CORRECTION => TRUE, -- Duty cycle correction, TRUE or FALSE
--      FACTORY_JF => X"F0F0",          -- FACTORY JF Values Suggested to be set to X"F0F0" 
--      PHASE_SHIFT => 0,      -- Amount of fixed phase shift from -255 to 1023
--      STARTUP_WAIT => FALSE) -- Delay configuration DONE until DCM LOCK, TRUE/FALSE
--   port map (
--      CLK0 => open,     -- 0 degree DCM CLK ouptput
--      CLK180 => open, -- 180 degree DCM CLK output
--      CLK270 => open, -- 270 degree DCM CLK output
--      CLK2X => open,		-- 2X DCM CLK output
--      CLK2X180 => open, -- 2X, 180 degree DCM CLK out
--      CLK90 => open,   -- 90 degree DCM CLK output
--      CLKDV => open,   -- Divided DCM CLK out (CLKDV_DIVIDE)
--      CLKFX => ckMul,   -- DCM CLK synthesis out (M/D)
--      CLKFX180 => open, -- 180 degree CLK synthesis out
--		DO => open,  -- 16-bit data output for Dynamic Reconfiguration Port (DRP)
--      LOCKED => open, -- DCM LOCK status output
--      PSDONE => open, -- Dynamic phase adjust done output
--      CLKFB => CLKFB,   -- DCM clock feedback
--      CLKIN => clk,   -- Clock input (from IBUFG, BUFG or DCM)
--      PSCLK => PSCLK,   -- Dynamic phase adjust clock input
--      PSEN => '0',     -- Dynamic phase adjust enable input
--      PSINCDEC => '0', -- Dynamic phase adjust increment/decrement
--      RST =>'0'        -- DCM asynchronous reset input
--   );
--

	  
end pulsewm_arch;
